@@ -1,4 +1,4 @@
-from .base import Button
+from . import Button
 from django.utils.translation import gettext as _
 from model_admin.hooks.buttons.entity.button import ButtonEntity
 
