@@ -3,7 +3,7 @@ from wagtail.admin import messages
 from wagtail.contrib.modeladmin.views import InstanceSpecificView
 from django.utils.translation import gettext as _
 
-from model_admin.utils.duplicate import DuplicateObject
+from model_admin.hooks.buttons.actions.duplicate import DuplicateObject
 
 
 class DuplicateView(InstanceSpecificView):
